@@ -9,6 +9,8 @@ class SynchronizeUsers(threading.Thread):
 	def __init__(self, 
 		# pass the r3stapi.RestAPI object.
 		restapi=None,
+		# show the daemon logs.
+		silent=False,
 		# the synchronize interval in minutes (default: synchronizes once per 60 min).
 		synchronize_interval=60,
 		# the sleep interval in minutes (default: checks synchronize interval once per 15 min).
@@ -16,6 +18,7 @@ class SynchronizeUsers(threading.Thread):
 	):
 		threading.Thread.__init__(self)
 		self.restapi = restapi
+		self.silent = silent
 		self.synchronize_interval = synchronize_interval
 		self.sleep_interval = sleep_interval
 	def run(self):
@@ -28,6 +31,6 @@ class SynchronizeUsers(threading.Thread):
 				new = date.compare(increased, date.timestamp) in ["present", "past"]
 			if new:
 				last = date.timestamp
-				response = self.restapi.synchronize_users(silent=True)
+				response = self.restapi.synchronize_users(silent=self.silent)
 				r3sponse.log(response, log_level=-1, save_errors=True)
 			time.sleep(self.sleep_interval*60)
\ No newline at end of file
