@@ -349,11 +349,10 @@ class RestAPI(object):
 		# check-remove double subscriptions.
 		if self.remove_double_subscriptions:
 			rank, plan, cancel_subs = None, None, {}
-			for uid, plans in subscriptions.items():
-				for plan, info in plans.items():
-					print("info:", info)
-					if info["plan_active_status"]:
-						response = self.__get_plan_by_plan_id__(info["plan_id"])
+			for uid, sub_info in subscriptions.items():
+				for plan, plan_info in sub_info["plans"].items():
+					if plan_info["plan_active_status"]:
+						response = self.__get_plan_by_plan_id__(plan_info["plan_id"])
 						if response["error"] != None: 
 							if silent == False: print(f"Error: {response['error']}")
 							return response
@@ -368,7 +367,7 @@ class RestAPI(object):
 								if plan not in ["free"]:
 									cancel_subs[uid].append(plan)
 								rank, plan = int(l_rank), str(l_plan)
-					if silent == False: print(f"Found subscription {uid}:{l_plan}, active: {info['plan_active_status']}.")	
+					if silent == False: print(f"Found subscription {uid}:{l_plan}, active: {plan_info['plan_active_status']}.")	
 			for uid, plans in cancel_subs.items():
 				for plan in plans:
 					if silent == False: print(f"Canceling double subscription {uid}:{l_plan}.")	
